#! /bin/sh
#
# skeleton	example file to build /etc/init.d/ scripts.
#		This file should be used to construct scripts for /etc/init.d.
#
#		Written by Miquel van Smoorenburg <miquels@cistron.nl>.
#		Modified for Debian 
#		by Ian Murdock <imurdock@gnu.ai.mit.edu>.
#
# Version:	@(#)skeleton  1.9  26-Feb-2001  miquels@cistron.nl
#

PATH=/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin
NAME=cybercluster
DESC=cybercluster

PGVERSION=8.2.3
PGMAJORVERSION=`echo "$PGVERSION" | sed 's/^\([0-9]*\.[0-9]*\).*$/\1/'`

PGENGINE=/usr/bin
PGPORT=5432
PGDATA=/var/lib/postgresql/data
PGLOG=/var/lib/postgresql/pgstartup.log
export PGDATA
export PGPORT

[ -f "$PGENGINE/postgres" ] || exit 1

# Include cybercluster defaults if available
if [ -f /etc/default/cybercluster ] ; then
	. /etc/default/cybercluster
fi

set -e

case "$1" in
  start)

	# Check for the PGDATA structure
	if [ -f "$PGDATA/PG_VERSION" ] && [ -d "$PGDATA/base" ]
	then
	# Check version of existing PGDATA

		if [ x`cat "$PGDATA/PG_VERSION"` != x"$PGMAJORVERSION" ]
		then
			SYSDOCDIR="(Your System's documentation directory)"
			if [ -d "/usr/doc/postgresql" ]
			then
				SYSDOCDIR=/usr/doc
			fi
			if [ -d "/usr/share/doc/postgresql" ]
			then
				SYSDOCDIR=/usr/share/doc
			fi
			if [ -d "/usr/doc/packages/postgresql" ]
			then
				SYSDOCDIR=/usr/doc/packages
			fi
			if [ -d "/usr/share/doc/packages/postgresql" ]
			then
				SYSDOCDIR=/usr/share/doc/packages
			fi
			echo
			echo $"An old version of the database format was found."
			echo $"You need to upgrade the data format before using PostgreSQL."
			echo $"See $SYSDOCDIR/postgresql-$PGVERSION/README.rpm-dist for more information."
			exit 1
		fi

	# No existing PGDATA! Initdb it.

	else
		echo -n $"Initializing database: "
		if [ ! -e "$PGDATA" -a ! -h "$PGDATA" ]
		then
			mkdir -p "$PGDATA" || exit 1
			chown postgres.postgres "$PGDATA"
			chmod go-rwx "$PGDATA"
		fi
		# Initialize the database
		su - postgres -m -c "$PGENGINE/initdb --pgdata='$PGDATA' --auth='ident sameuser'" >> "$PGLOG" 2>&1 < /dev/null
		# Create directory for postmaster log
		mkdir "$PGDATA/pg_log"
		chown postgres:postgres "$PGDATA/pg_log"
		chmod go-rwx "$PGDATA/pg_log"

		[ -f "$PGDATA/PG_VERSION" ] && echo success
		[ ! -f "$PGDATA/PG_VERSION" ] && echo failure
		echo
 	fi

	echo -n "Starting $DESC: "

	su - postgres -m -c "$PGENGINE/postmaster -p '$PGPORT' -D '$PGDATA' ${PGOPTS} &" >> "$PGLOG" 2>&1 < /dev/null
	sleep 2
	pid=`pidof -s "$PGENGINE/postmaster"`
	if [ $pid ] && [ -f "$PGDATA/postmaster.pid" ]
	then
		echo "$NAME."
		head -n 1 "$PGDATA/postmaster.pid" > "/var/run/postmaster.${PGPORT}.pid"
		echo
	else
		echo failed
		echo
		script_result=1
	fi


	;;
  stop)
	echo -n "Stopping $DESC: "

	su - postgres -m -c "$PGENGINE/pg_ctl stop -D '$PGDATA' -s -m fast" > /dev/null 2>&1 < /dev/null
	ret=$? 
	if [ $ret -eq 0 ]
	then
		echo "$NAME."
	else
		echo failed
		script_result=1
	fi
	echo
	rm -f "/var/run/postmaster.${PGPORT}.pid"
	;;
  #reload)
	#
	#	If the daemon can reload its config files on the fly
	#	for example by sending it SIGHUP, do it here.
	#
	#	If the daemon responds to changes in its config file
	#	directly anyway, make this a do-nothing entry.
	#
	# echo "Reloading $DESC configuration files."
	# start-stop-daemon --stop --signal 1 --quiet --pidfile \
	#	/var/run/$NAME.pid --exec $DAEMON
  #;;
  restart|force-reload)
	#
	#	If the "reload" option is implemented, move the "force-reload"
	#	option to the "reload" entry above. If not, "force-reload" is
	#	just the same as "restart".
	#
	$0 stop
	sleep 1
	$0 start
	;;
  *)
	N=/etc/init.d/$NAME
	# echo "Usage: $N {start|stop|restart|reload|force-reload}" >&2
	echo "Usage: $N {start|stop|restart|force-reload}" >&2
	exit 1
	;;
esac

exit 0
