#include "postgres.h"
#include "postgres_fe.h"

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <replicate_com.h>
#include <pthread.h>
#include "libpq-fe.h"
#include "libpq-int.h"
#include "fe-auth.h"  

#include "pgreplicate.h"

ConfDataType * ConfData_Top = (ConfDataType *)NULL;
ConfDataType * ConfData_End = (ConfDataType *)NULL;
int PGR_Replication_Timeout = 60;

RPLCChecker	comm;
fd_set		rmask;
struct timeval	timeout;

int main(int argc, char **argv)
{
        int		ret, sock;
        unsigned short	port;

        printf("RPLMonitor v1.0\n");
        if (argc != 5)
        {
          printf("Usage: %s hostname port dbname table\n", argv[0]);
          return 0;
        }
        if (atoi(argv[2]) > 0)
        {
#ifdef WIN32
          WORD wVersionRequested;
          WSADATA wsaData;
          int err;

          wVersionRequested = MAKEWORD( 1, 1 );
          err = WSAStartup( wVersionRequested, &wsaData );
          if ( err != 0 )
          {
            printf("WSAStartup failed");
            return 0;
          }
#endif
          port = atoi(argv[2]);
          ret = PGR_Create_Socket_Connect(&sock, argv[1], port);
          if (ret != STATUS_OK)
          {
            printf("PGR_Create_Socket_Connect() failed\n");
            return 1;
          }

          strncpy(comm.dbname, argv[3], DBNAME_MAX_LENGTH);
          strncpy(comm.table, argv[4], TABLENAME_MAX_LENGTH);
          ret = write(sock, &comm, sizeof(comm));

          timeout.tv_sec = PGR_Replication_Timeout;
          timeout.tv_usec = 0;
          FD_ZERO(&rmask);
          FD_SET(sock, &rmask);
          ret = select(sock+1, &rmask, (fd_set *)NULL, (fd_set *)NULL, &timeout);

          ret = read(sock, &comm, sizeof(comm));
          if (ret == sizeof(comm))
          {
            comm.result = ntohl(comm.result);
            printf("Consistency check for DB=%s TABLE=%s %s\n"
                    "Reported status: %s\n",
                      argv[3], argv[4],
                      comm.result == 0 ? "succeeded" : "failed",
                      comm.resulttext);
          }
          else
          {
            printf("Error. Expected %ld bytes, got %d\n", sizeof(comm), ret);
          }

          PGR_Close_Sock(&sock);

#ifdef WIN32
          WSACleanup();
#endif
        }
        return 0;
}
